@@ -21,22 +21,28 @@
 #define CXXTOOLS_REFCOUNTED_H
 
 #include <cxxtools/noncopyable.h>
+#include <cxxtools/atomicity.h>
 
 namespace cxxtools
 {
   class RefCounted : private NonCopyable
   {
-      unsigned refs;
+      atomic_t refs;
 
     public:
       RefCounted()
         : refs(0)
         { }
+
+      explicit RefCounted(unsigned refs_)
+        : refs(refs_)
+        { }
+
       virtual ~RefCounted()  { }
 
-      virtual void addRef()  { ++refs; }
-      virtual void release() { if (--refs == 0) delete this; }
-      unsigned getRefs() const   { return refs; }
+      virtual atomic_t addRef()  { return atomicIncrement(refs); }
+      virtual void release() { if (atomicDecrement(refs) == 0) delete this; }
+      atomic_t getRefs() const   { return refs; }
   };
 }
 
